#' spex
#'
#' @name spex
#' @section Spatial Extent:
#' \tabular{ll}{
#'  \code{\link{spex}} \tab function to produce a fully fledged Spatial object extent \cr
#' }
#' @docType package
NULL

#' The 'lux' Spatial Polygons from the 'raster' package.
#'
#' @name lux
#' @format \code{\link[sp]{SpatialPolygonsDataFrame}} with columns:
#' \itemize{
#'  \item ID_1
#'  \item NAME_1
#'  \item ID_2
#'  \item NAME_2
#'  \item AREA
#' }
#' @docType data
#' @examples
#' library(sp)
#' plot(lux)
NULL

#' A polygon data set with `sf` class. 
#' 
#' @name psf
#' @docType data
NULL

